@@ -2,15 +2,20 @@ package String::Multibyte::Grapheme;
 
 require 5.008;
 use vars qw($VERSION);
-$VERSION = '1.10';
+$VERSION = '1.12';
 
 our $CRLF    = qr/(?:\cM\cJ)/;
 our $Control = qr/(?!\cM\cJ)[\p{Zl}\p{Zp}\p{Cc}\p{Cf}]/;
 our $Any     = qr/[^\p{Zl}\p{Zp}\p{Cc}\p{Cf}]/;
 
-eval { ' ' =~ /\p{GraphemeExtend}/ };
-our $Extend  = $@ ? qr/[\p{Mn}\p{Me}\p{OtherGraphemeExtend}]/
-		  : qr/\p{GraphemeExtend}/;
+our $Extend;
+eval q{ ' ' =~ /\p{GraphemeExtend}/ }; # since 5.12 ?
+if ($@) {
+    eval q{ $Extend  = qr/[\p{Mn}\p{Me}\p{OtherGraphemeExtend}]/ };
+} else {
+    eval q{ $Extend = qr/\p{GraphemeExtend}/ };
+}
+
 our $HangL   = qr/[\x{1100}-\x{1159}\x{115F}]/; # Hangul Jamo Leading Consonant
 our $HangV   = qr/[\x{1160}-\x{11A2}]/; # Hangul Jamo Vowel
 our $HangT   = qr/[\x{11A8}-\x{11F9}]/; # Hangul Jamo Trailing Consonant
